"""Wrapper classes for Angzarr proto types.

Each wrapper takes a protobuf message in its constructor and provides
extension methods as instance methods.
"""

from typing import Optional, List, Type, TypeVar
from uuid import UUID as PyUUID

from .proto.angzarr import (
    Cover,
    EventBook,
    CommandBook,
    Query,
    EventPage,
    CommandPage,
    CommandResponse,
)
from .helpers import (
    UNKNOWN_DOMAIN,
    DEFAULT_EDITION,
    type_url_matches,
)

T = TypeVar("T")
from inspect import signature as _mutmut_signature
from typing import Annotated
from typing import Callable
from typing import ClassVar


MutantDict = Annotated[dict[str, Callable], "Mutant"]


def _mutmut_trampoline(orig, mutants, call_args, call_kwargs, self_arg = None):
    """Forward call to original or mutated function, depending on the environment"""
    import os
    mutant_under_test = os.environ['MUTANT_UNDER_TEST']
    if mutant_under_test == 'fail':
        from mutmut.__main__ import MutmutProgrammaticFailException
        raise MutmutProgrammaticFailException('Failed programmatically')      
    elif mutant_under_test == 'stats':
        from mutmut.__main__ import record_trampoline_hit
        record_trampoline_hit(orig.__module__ + '.' + orig.__name__)
        result = orig(*call_args, **call_kwargs)
        return result
    prefix = orig.__module__ + '.' + orig.__name__ + '__mutmut_'
    if not mutant_under_test.startswith(prefix):
        result = orig(*call_args, **call_kwargs)
        return result
    mutant_name = mutant_under_test.rpartition('.')[-1]
    if self_arg is not None:
        # call to a class method where self is not bound
        result = mutants[mutant_name](self_arg, *call_args, **call_kwargs)
    else:
        result = mutants[mutant_name](*call_args, **call_kwargs)
    return result


class CoverW:
    """Wrapper for Cover proto with extension methods."""

    def xǁCoverWǁ__init____mutmut_orig(self, proto: Cover) -> None:
        self.proto = proto

    def xǁCoverWǁ__init____mutmut_1(self, proto: Cover) -> None:
        self.proto = None
    
    xǁCoverWǁ__init____mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCoverWǁ__init____mutmut_1': xǁCoverWǁ__init____mutmut_1
    }
    
    def __init__(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCoverWǁ__init____mutmut_orig"), object.__getattribute__(self, "xǁCoverWǁ__init____mutmut_mutants"), args, kwargs, self)
        return result 
    
    __init__.__signature__ = _mutmut_signature(xǁCoverWǁ__init____mutmut_orig)
    xǁCoverWǁ__init____mutmut_orig.__name__ = 'xǁCoverWǁ__init__'

    def xǁCoverWǁdomain__mutmut_orig(self) -> str:
        """Get the domain, or UNKNOWN_DOMAIN if missing."""
        if not self.proto.domain:
            return UNKNOWN_DOMAIN
        return self.proto.domain

    def xǁCoverWǁdomain__mutmut_1(self) -> str:
        """Get the domain, or UNKNOWN_DOMAIN if missing."""
        if self.proto.domain:
            return UNKNOWN_DOMAIN
        return self.proto.domain
    
    xǁCoverWǁdomain__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCoverWǁdomain__mutmut_1': xǁCoverWǁdomain__mutmut_1
    }
    
    def domain(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCoverWǁdomain__mutmut_orig"), object.__getattribute__(self, "xǁCoverWǁdomain__mutmut_mutants"), args, kwargs, self)
        return result 
    
    domain.__signature__ = _mutmut_signature(xǁCoverWǁdomain__mutmut_orig)
    xǁCoverWǁdomain__mutmut_orig.__name__ = 'xǁCoverWǁdomain'

    def correlation_id(self) -> str:
        """Get the correlation_id, or empty string if missing."""
        return self.proto.correlation_id

    def xǁCoverWǁhas_correlation_id__mutmut_orig(self) -> bool:
        """Return True if the correlation_id is present and non-empty."""
        return bool(self.proto.correlation_id)

    def xǁCoverWǁhas_correlation_id__mutmut_1(self) -> bool:
        """Return True if the correlation_id is present and non-empty."""
        return bool(None)
    
    xǁCoverWǁhas_correlation_id__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCoverWǁhas_correlation_id__mutmut_1': xǁCoverWǁhas_correlation_id__mutmut_1
    }
    
    def has_correlation_id(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCoverWǁhas_correlation_id__mutmut_orig"), object.__getattribute__(self, "xǁCoverWǁhas_correlation_id__mutmut_mutants"), args, kwargs, self)
        return result 
    
    has_correlation_id.__signature__ = _mutmut_signature(xǁCoverWǁhas_correlation_id__mutmut_orig)
    xǁCoverWǁhas_correlation_id__mutmut_orig.__name__ = 'xǁCoverWǁhas_correlation_id'

    def xǁCoverWǁroot_uuid__mutmut_orig(self) -> Optional[PyUUID]:
        """Extract the root UUID."""
        if not self.proto.HasField("root"):
            return None
        try:
            return PyUUID(bytes=self.proto.root.value)
        except ValueError:
            return None

    def xǁCoverWǁroot_uuid__mutmut_1(self) -> Optional[PyUUID]:
        """Extract the root UUID."""
        if self.proto.HasField("root"):
            return None
        try:
            return PyUUID(bytes=self.proto.root.value)
        except ValueError:
            return None

    def xǁCoverWǁroot_uuid__mutmut_2(self) -> Optional[PyUUID]:
        """Extract the root UUID."""
        if not self.proto.HasField(None):
            return None
        try:
            return PyUUID(bytes=self.proto.root.value)
        except ValueError:
            return None

    def xǁCoverWǁroot_uuid__mutmut_3(self) -> Optional[PyUUID]:
        """Extract the root UUID."""
        if not self.proto.HasField("XXrootXX"):
            return None
        try:
            return PyUUID(bytes=self.proto.root.value)
        except ValueError:
            return None

    def xǁCoverWǁroot_uuid__mutmut_4(self) -> Optional[PyUUID]:
        """Extract the root UUID."""
        if not self.proto.HasField("ROOT"):
            return None
        try:
            return PyUUID(bytes=self.proto.root.value)
        except ValueError:
            return None

    def xǁCoverWǁroot_uuid__mutmut_5(self) -> Optional[PyUUID]:
        """Extract the root UUID."""
        if not self.proto.HasField("root"):
            return None
        try:
            return PyUUID(bytes=None)
        except ValueError:
            return None
    
    xǁCoverWǁroot_uuid__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCoverWǁroot_uuid__mutmut_1': xǁCoverWǁroot_uuid__mutmut_1, 
        'xǁCoverWǁroot_uuid__mutmut_2': xǁCoverWǁroot_uuid__mutmut_2, 
        'xǁCoverWǁroot_uuid__mutmut_3': xǁCoverWǁroot_uuid__mutmut_3, 
        'xǁCoverWǁroot_uuid__mutmut_4': xǁCoverWǁroot_uuid__mutmut_4, 
        'xǁCoverWǁroot_uuid__mutmut_5': xǁCoverWǁroot_uuid__mutmut_5
    }
    
    def root_uuid(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCoverWǁroot_uuid__mutmut_orig"), object.__getattribute__(self, "xǁCoverWǁroot_uuid__mutmut_mutants"), args, kwargs, self)
        return result 
    
    root_uuid.__signature__ = _mutmut_signature(xǁCoverWǁroot_uuid__mutmut_orig)
    xǁCoverWǁroot_uuid__mutmut_orig.__name__ = 'xǁCoverWǁroot_uuid'

    def xǁCoverWǁroot_id_hex__mutmut_orig(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        if not self.proto.HasField("root"):
            return ""
        return self.proto.root.value.hex()

    def xǁCoverWǁroot_id_hex__mutmut_1(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        if self.proto.HasField("root"):
            return ""
        return self.proto.root.value.hex()

    def xǁCoverWǁroot_id_hex__mutmut_2(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        if not self.proto.HasField(None):
            return ""
        return self.proto.root.value.hex()

    def xǁCoverWǁroot_id_hex__mutmut_3(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        if not self.proto.HasField("XXrootXX"):
            return ""
        return self.proto.root.value.hex()

    def xǁCoverWǁroot_id_hex__mutmut_4(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        if not self.proto.HasField("ROOT"):
            return ""
        return self.proto.root.value.hex()

    def xǁCoverWǁroot_id_hex__mutmut_5(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        if not self.proto.HasField("root"):
            return "XXXX"
        return self.proto.root.value.hex()
    
    xǁCoverWǁroot_id_hex__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCoverWǁroot_id_hex__mutmut_1': xǁCoverWǁroot_id_hex__mutmut_1, 
        'xǁCoverWǁroot_id_hex__mutmut_2': xǁCoverWǁroot_id_hex__mutmut_2, 
        'xǁCoverWǁroot_id_hex__mutmut_3': xǁCoverWǁroot_id_hex__mutmut_3, 
        'xǁCoverWǁroot_id_hex__mutmut_4': xǁCoverWǁroot_id_hex__mutmut_4, 
        'xǁCoverWǁroot_id_hex__mutmut_5': xǁCoverWǁroot_id_hex__mutmut_5
    }
    
    def root_id_hex(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCoverWǁroot_id_hex__mutmut_orig"), object.__getattribute__(self, "xǁCoverWǁroot_id_hex__mutmut_mutants"), args, kwargs, self)
        return result 
    
    root_id_hex.__signature__ = _mutmut_signature(xǁCoverWǁroot_id_hex__mutmut_orig)
    xǁCoverWǁroot_id_hex__mutmut_orig.__name__ = 'xǁCoverWǁroot_id_hex'

    def xǁCoverWǁedition__mutmut_orig(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        if not self.proto.HasField("edition") or not self.proto.edition.name:
            return DEFAULT_EDITION
        return self.proto.edition.name

    def xǁCoverWǁedition__mutmut_1(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        if not self.proto.HasField("edition") and not self.proto.edition.name:
            return DEFAULT_EDITION
        return self.proto.edition.name

    def xǁCoverWǁedition__mutmut_2(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        if self.proto.HasField("edition") or not self.proto.edition.name:
            return DEFAULT_EDITION
        return self.proto.edition.name

    def xǁCoverWǁedition__mutmut_3(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        if not self.proto.HasField(None) or not self.proto.edition.name:
            return DEFAULT_EDITION
        return self.proto.edition.name

    def xǁCoverWǁedition__mutmut_4(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        if not self.proto.HasField("XXeditionXX") or not self.proto.edition.name:
            return DEFAULT_EDITION
        return self.proto.edition.name

    def xǁCoverWǁedition__mutmut_5(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        if not self.proto.HasField("EDITION") or not self.proto.edition.name:
            return DEFAULT_EDITION
        return self.proto.edition.name

    def xǁCoverWǁedition__mutmut_6(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        if not self.proto.HasField("edition") or self.proto.edition.name:
            return DEFAULT_EDITION
        return self.proto.edition.name
    
    xǁCoverWǁedition__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCoverWǁedition__mutmut_1': xǁCoverWǁedition__mutmut_1, 
        'xǁCoverWǁedition__mutmut_2': xǁCoverWǁedition__mutmut_2, 
        'xǁCoverWǁedition__mutmut_3': xǁCoverWǁedition__mutmut_3, 
        'xǁCoverWǁedition__mutmut_4': xǁCoverWǁedition__mutmut_4, 
        'xǁCoverWǁedition__mutmut_5': xǁCoverWǁedition__mutmut_5, 
        'xǁCoverWǁedition__mutmut_6': xǁCoverWǁedition__mutmut_6
    }
    
    def edition(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCoverWǁedition__mutmut_orig"), object.__getattribute__(self, "xǁCoverWǁedition__mutmut_mutants"), args, kwargs, self)
        return result 
    
    edition.__signature__ = _mutmut_signature(xǁCoverWǁedition__mutmut_orig)
    xǁCoverWǁedition__mutmut_orig.__name__ = 'xǁCoverWǁedition'

    def xǁCoverWǁedition_opt__mutmut_orig(self) -> Optional[str]:
        """Return the edition name as Optional, None if not set."""
        if not self.proto.HasField("edition") or not self.proto.edition.name:
            return None
        return self.proto.edition.name

    def xǁCoverWǁedition_opt__mutmut_1(self) -> Optional[str]:
        """Return the edition name as Optional, None if not set."""
        if not self.proto.HasField("edition") and not self.proto.edition.name:
            return None
        return self.proto.edition.name

    def xǁCoverWǁedition_opt__mutmut_2(self) -> Optional[str]:
        """Return the edition name as Optional, None if not set."""
        if self.proto.HasField("edition") or not self.proto.edition.name:
            return None
        return self.proto.edition.name

    def xǁCoverWǁedition_opt__mutmut_3(self) -> Optional[str]:
        """Return the edition name as Optional, None if not set."""
        if not self.proto.HasField(None) or not self.proto.edition.name:
            return None
        return self.proto.edition.name

    def xǁCoverWǁedition_opt__mutmut_4(self) -> Optional[str]:
        """Return the edition name as Optional, None if not set."""
        if not self.proto.HasField("XXeditionXX") or not self.proto.edition.name:
            return None
        return self.proto.edition.name

    def xǁCoverWǁedition_opt__mutmut_5(self) -> Optional[str]:
        """Return the edition name as Optional, None if not set."""
        if not self.proto.HasField("EDITION") or not self.proto.edition.name:
            return None
        return self.proto.edition.name

    def xǁCoverWǁedition_opt__mutmut_6(self) -> Optional[str]:
        """Return the edition name as Optional, None if not set."""
        if not self.proto.HasField("edition") or self.proto.edition.name:
            return None
        return self.proto.edition.name
    
    xǁCoverWǁedition_opt__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCoverWǁedition_opt__mutmut_1': xǁCoverWǁedition_opt__mutmut_1, 
        'xǁCoverWǁedition_opt__mutmut_2': xǁCoverWǁedition_opt__mutmut_2, 
        'xǁCoverWǁedition_opt__mutmut_3': xǁCoverWǁedition_opt__mutmut_3, 
        'xǁCoverWǁedition_opt__mutmut_4': xǁCoverWǁedition_opt__mutmut_4, 
        'xǁCoverWǁedition_opt__mutmut_5': xǁCoverWǁedition_opt__mutmut_5, 
        'xǁCoverWǁedition_opt__mutmut_6': xǁCoverWǁedition_opt__mutmut_6
    }
    
    def edition_opt(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCoverWǁedition_opt__mutmut_orig"), object.__getattribute__(self, "xǁCoverWǁedition_opt__mutmut_mutants"), args, kwargs, self)
        return result 
    
    edition_opt.__signature__ = _mutmut_signature(xǁCoverWǁedition_opt__mutmut_orig)
    xǁCoverWǁedition_opt__mutmut_orig.__name__ = 'xǁCoverWǁedition_opt'

    def routing_key(self) -> str:
        """Compute the bus routing key."""
        return self.domain()

    def cache_key(self) -> str:
        """Generate a cache key based on domain + root."""
        return f"{self.domain()}:{self.root_id_hex()}"


class EventBookW:
    """Wrapper for EventBook proto with extension methods."""

    def xǁEventBookWǁ__init____mutmut_orig(self, proto: EventBook) -> None:
        self.proto = proto

    def xǁEventBookWǁ__init____mutmut_1(self, proto: EventBook) -> None:
        self.proto = None
    
    xǁEventBookWǁ__init____mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁ__init____mutmut_1': xǁEventBookWǁ__init____mutmut_1
    }
    
    def __init__(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁ__init____mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁ__init____mutmut_mutants"), args, kwargs, self)
        return result 
    
    __init__.__signature__ = _mutmut_signature(xǁEventBookWǁ__init____mutmut_orig)
    xǁEventBookWǁ__init____mutmut_orig.__name__ = 'xǁEventBookWǁ__init__'

    def next_sequence(self) -> int:
        """Return the next sequence number."""
        return self.proto.next_sequence

    def xǁEventBookWǁpages__mutmut_orig(self) -> List["EventPageW"]:
        """Return the event pages as wrapped EventPageW instances."""
        return [EventPageW(p) for p in self.proto.pages]

    def xǁEventBookWǁpages__mutmut_1(self) -> List["EventPageW"]:
        """Return the event pages as wrapped EventPageW instances."""
        return [EventPageW(None) for p in self.proto.pages]
    
    xǁEventBookWǁpages__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁpages__mutmut_1': xǁEventBookWǁpages__mutmut_1
    }
    
    def pages(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁpages__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁpages__mutmut_mutants"), args, kwargs, self)
        return result 
    
    pages.__signature__ = _mutmut_signature(xǁEventBookWǁpages__mutmut_orig)
    xǁEventBookWǁpages__mutmut_orig.__name__ = 'xǁEventBookWǁpages'

    def xǁEventBookWǁ_cover__mutmut_orig(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("cover"):
            return None
        return self.proto.cover

    def xǁEventBookWǁ_cover__mutmut_1(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if self.proto.HasField("cover"):
            return None
        return self.proto.cover

    def xǁEventBookWǁ_cover__mutmut_2(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField(None):
            return None
        return self.proto.cover

    def xǁEventBookWǁ_cover__mutmut_3(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("XXcoverXX"):
            return None
        return self.proto.cover

    def xǁEventBookWǁ_cover__mutmut_4(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("COVER"):
            return None
        return self.proto.cover
    
    xǁEventBookWǁ_cover__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁ_cover__mutmut_1': xǁEventBookWǁ_cover__mutmut_1, 
        'xǁEventBookWǁ_cover__mutmut_2': xǁEventBookWǁ_cover__mutmut_2, 
        'xǁEventBookWǁ_cover__mutmut_3': xǁEventBookWǁ_cover__mutmut_3, 
        'xǁEventBookWǁ_cover__mutmut_4': xǁEventBookWǁ_cover__mutmut_4
    }
    
    def _cover(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁ_cover__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁ_cover__mutmut_mutants"), args, kwargs, self)
        return result 
    
    _cover.__signature__ = _mutmut_signature(xǁEventBookWǁ_cover__mutmut_orig)
    xǁEventBookWǁ_cover__mutmut_orig.__name__ = 'xǁEventBookWǁ_cover'

    def xǁEventBookWǁdomain__mutmut_orig(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁEventBookWǁdomain__mutmut_1(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = None
        if cover is None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁEventBookWǁdomain__mutmut_2(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None and not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁEventBookWǁdomain__mutmut_3(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is not None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁEventBookWǁdomain__mutmut_4(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None or cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain
    
    xǁEventBookWǁdomain__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁdomain__mutmut_1': xǁEventBookWǁdomain__mutmut_1, 
        'xǁEventBookWǁdomain__mutmut_2': xǁEventBookWǁdomain__mutmut_2, 
        'xǁEventBookWǁdomain__mutmut_3': xǁEventBookWǁdomain__mutmut_3, 
        'xǁEventBookWǁdomain__mutmut_4': xǁEventBookWǁdomain__mutmut_4
    }
    
    def domain(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁdomain__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁdomain__mutmut_mutants"), args, kwargs, self)
        return result 
    
    domain.__signature__ = _mutmut_signature(xǁEventBookWǁdomain__mutmut_orig)
    xǁEventBookWǁdomain__mutmut_orig.__name__ = 'xǁEventBookWǁdomain'

    def xǁEventBookWǁcorrelation_id__mutmut_orig(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is None:
            return ""
        return cover.correlation_id

    def xǁEventBookWǁcorrelation_id__mutmut_1(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = None
        if cover is None:
            return ""
        return cover.correlation_id

    def xǁEventBookWǁcorrelation_id__mutmut_2(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is not None:
            return ""
        return cover.correlation_id

    def xǁEventBookWǁcorrelation_id__mutmut_3(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is None:
            return "XXXX"
        return cover.correlation_id
    
    xǁEventBookWǁcorrelation_id__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁcorrelation_id__mutmut_1': xǁEventBookWǁcorrelation_id__mutmut_1, 
        'xǁEventBookWǁcorrelation_id__mutmut_2': xǁEventBookWǁcorrelation_id__mutmut_2, 
        'xǁEventBookWǁcorrelation_id__mutmut_3': xǁEventBookWǁcorrelation_id__mutmut_3
    }
    
    def correlation_id(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁcorrelation_id__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁcorrelation_id__mutmut_mutants"), args, kwargs, self)
        return result 
    
    correlation_id.__signature__ = _mutmut_signature(xǁEventBookWǁcorrelation_id__mutmut_orig)
    xǁEventBookWǁcorrelation_id__mutmut_orig.__name__ = 'xǁEventBookWǁcorrelation_id'

    def xǁEventBookWǁhas_correlation_id__mutmut_orig(self) -> bool:
        """Return True if the correlation_id is present and non-empty."""
        return bool(self.correlation_id())

    def xǁEventBookWǁhas_correlation_id__mutmut_1(self) -> bool:
        """Return True if the correlation_id is present and non-empty."""
        return bool(None)
    
    xǁEventBookWǁhas_correlation_id__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁhas_correlation_id__mutmut_1': xǁEventBookWǁhas_correlation_id__mutmut_1
    }
    
    def has_correlation_id(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁhas_correlation_id__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁhas_correlation_id__mutmut_mutants"), args, kwargs, self)
        return result 
    
    has_correlation_id.__signature__ = _mutmut_signature(xǁEventBookWǁhas_correlation_id__mutmut_orig)
    xǁEventBookWǁhas_correlation_id__mutmut_orig.__name__ = 'xǁEventBookWǁhas_correlation_id'

    def xǁEventBookWǁroot_uuid__mutmut_orig(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁEventBookWǁroot_uuid__mutmut_1(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = None
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁEventBookWǁroot_uuid__mutmut_2(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None and not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁEventBookWǁroot_uuid__mutmut_3(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is not None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁEventBookWǁroot_uuid__mutmut_4(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁEventBookWǁroot_uuid__mutmut_5(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField(None):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁEventBookWǁroot_uuid__mutmut_6(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("XXrootXX"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁEventBookWǁroot_uuid__mutmut_7(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("ROOT"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁEventBookWǁroot_uuid__mutmut_8(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=None)
        except ValueError:
            return None
    
    xǁEventBookWǁroot_uuid__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁroot_uuid__mutmut_1': xǁEventBookWǁroot_uuid__mutmut_1, 
        'xǁEventBookWǁroot_uuid__mutmut_2': xǁEventBookWǁroot_uuid__mutmut_2, 
        'xǁEventBookWǁroot_uuid__mutmut_3': xǁEventBookWǁroot_uuid__mutmut_3, 
        'xǁEventBookWǁroot_uuid__mutmut_4': xǁEventBookWǁroot_uuid__mutmut_4, 
        'xǁEventBookWǁroot_uuid__mutmut_5': xǁEventBookWǁroot_uuid__mutmut_5, 
        'xǁEventBookWǁroot_uuid__mutmut_6': xǁEventBookWǁroot_uuid__mutmut_6, 
        'xǁEventBookWǁroot_uuid__mutmut_7': xǁEventBookWǁroot_uuid__mutmut_7, 
        'xǁEventBookWǁroot_uuid__mutmut_8': xǁEventBookWǁroot_uuid__mutmut_8
    }
    
    def root_uuid(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁroot_uuid__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁroot_uuid__mutmut_mutants"), args, kwargs, self)
        return result 
    
    root_uuid.__signature__ = _mutmut_signature(xǁEventBookWǁroot_uuid__mutmut_orig)
    xǁEventBookWǁroot_uuid__mutmut_orig.__name__ = 'xǁEventBookWǁroot_uuid'

    def xǁEventBookWǁroot_id_hex__mutmut_orig(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return ""
        return cover.root.value.hex()

    def xǁEventBookWǁroot_id_hex__mutmut_1(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = None
        if cover is None or not cover.HasField("root"):
            return ""
        return cover.root.value.hex()

    def xǁEventBookWǁroot_id_hex__mutmut_2(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = self._cover()
        if cover is None and not cover.HasField("root"):
            return ""
        return cover.root.value.hex()

    def xǁEventBookWǁroot_id_hex__mutmut_3(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = self._cover()
        if cover is not None or not cover.HasField("root"):
            return ""
        return cover.root.value.hex()

    def xǁEventBookWǁroot_id_hex__mutmut_4(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = self._cover()
        if cover is None or cover.HasField("root"):
            return ""
        return cover.root.value.hex()

    def xǁEventBookWǁroot_id_hex__mutmut_5(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = self._cover()
        if cover is None or not cover.HasField(None):
            return ""
        return cover.root.value.hex()

    def xǁEventBookWǁroot_id_hex__mutmut_6(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = self._cover()
        if cover is None or not cover.HasField("XXrootXX"):
            return ""
        return cover.root.value.hex()

    def xǁEventBookWǁroot_id_hex__mutmut_7(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = self._cover()
        if cover is None or not cover.HasField("ROOT"):
            return ""
        return cover.root.value.hex()

    def xǁEventBookWǁroot_id_hex__mutmut_8(self) -> str:
        """Return the root UUID as a hex string, or empty string if missing."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return "XXXX"
        return cover.root.value.hex()
    
    xǁEventBookWǁroot_id_hex__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁroot_id_hex__mutmut_1': xǁEventBookWǁroot_id_hex__mutmut_1, 
        'xǁEventBookWǁroot_id_hex__mutmut_2': xǁEventBookWǁroot_id_hex__mutmut_2, 
        'xǁEventBookWǁroot_id_hex__mutmut_3': xǁEventBookWǁroot_id_hex__mutmut_3, 
        'xǁEventBookWǁroot_id_hex__mutmut_4': xǁEventBookWǁroot_id_hex__mutmut_4, 
        'xǁEventBookWǁroot_id_hex__mutmut_5': xǁEventBookWǁroot_id_hex__mutmut_5, 
        'xǁEventBookWǁroot_id_hex__mutmut_6': xǁEventBookWǁroot_id_hex__mutmut_6, 
        'xǁEventBookWǁroot_id_hex__mutmut_7': xǁEventBookWǁroot_id_hex__mutmut_7, 
        'xǁEventBookWǁroot_id_hex__mutmut_8': xǁEventBookWǁroot_id_hex__mutmut_8
    }
    
    def root_id_hex(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁroot_id_hex__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁroot_id_hex__mutmut_mutants"), args, kwargs, self)
        return result 
    
    root_id_hex.__signature__ = _mutmut_signature(xǁEventBookWǁroot_id_hex__mutmut_orig)
    xǁEventBookWǁroot_id_hex__mutmut_orig.__name__ = 'xǁEventBookWǁroot_id_hex'

    def xǁEventBookWǁedition__mutmut_orig(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is None or not cover.HasField("edition") or not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_1(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = None
        if cover is None or not cover.HasField("edition") or not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_2(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is None or not cover.HasField("edition") and not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_3(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is None and not cover.HasField("edition") or not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_4(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is not None or not cover.HasField("edition") or not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_5(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is None or cover.HasField("edition") or not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_6(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is None or not cover.HasField(None) or not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_7(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is None or not cover.HasField("XXeditionXX") or not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_8(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is None or not cover.HasField("EDITION") or not cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name

    def xǁEventBookWǁedition__mutmut_9(self) -> str:
        """Return the edition name, defaulting to DEFAULT_EDITION."""
        cover = self._cover()
        if cover is None or not cover.HasField("edition") or cover.edition.name:
            return DEFAULT_EDITION
        return cover.edition.name
    
    xǁEventBookWǁedition__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁedition__mutmut_1': xǁEventBookWǁedition__mutmut_1, 
        'xǁEventBookWǁedition__mutmut_2': xǁEventBookWǁedition__mutmut_2, 
        'xǁEventBookWǁedition__mutmut_3': xǁEventBookWǁedition__mutmut_3, 
        'xǁEventBookWǁedition__mutmut_4': xǁEventBookWǁedition__mutmut_4, 
        'xǁEventBookWǁedition__mutmut_5': xǁEventBookWǁedition__mutmut_5, 
        'xǁEventBookWǁedition__mutmut_6': xǁEventBookWǁedition__mutmut_6, 
        'xǁEventBookWǁedition__mutmut_7': xǁEventBookWǁedition__mutmut_7, 
        'xǁEventBookWǁedition__mutmut_8': xǁEventBookWǁedition__mutmut_8, 
        'xǁEventBookWǁedition__mutmut_9': xǁEventBookWǁedition__mutmut_9
    }
    
    def edition(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁedition__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁedition__mutmut_mutants"), args, kwargs, self)
        return result 
    
    edition.__signature__ = _mutmut_signature(xǁEventBookWǁedition__mutmut_orig)
    xǁEventBookWǁedition__mutmut_orig.__name__ = 'xǁEventBookWǁedition'

    def routing_key(self) -> str:
        """Compute the bus routing key."""
        return self.domain()

    def cache_key(self) -> str:
        """Generate a cache key based on domain + root."""
        return f"{self.domain()}:{self.root_id_hex()}"

    def xǁEventBookWǁcover_wrapper__mutmut_orig(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁEventBookWǁcover_wrapper__mutmut_1(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = None
        if cover is None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁEventBookWǁcover_wrapper__mutmut_2(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is not None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁEventBookWǁcover_wrapper__mutmut_3(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(None)
        return CoverW(cover)

    def xǁEventBookWǁcover_wrapper__mutmut_4(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(Cover())
        return CoverW(None)
    
    xǁEventBookWǁcover_wrapper__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventBookWǁcover_wrapper__mutmut_1': xǁEventBookWǁcover_wrapper__mutmut_1, 
        'xǁEventBookWǁcover_wrapper__mutmut_2': xǁEventBookWǁcover_wrapper__mutmut_2, 
        'xǁEventBookWǁcover_wrapper__mutmut_3': xǁEventBookWǁcover_wrapper__mutmut_3, 
        'xǁEventBookWǁcover_wrapper__mutmut_4': xǁEventBookWǁcover_wrapper__mutmut_4
    }
    
    def cover_wrapper(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventBookWǁcover_wrapper__mutmut_orig"), object.__getattribute__(self, "xǁEventBookWǁcover_wrapper__mutmut_mutants"), args, kwargs, self)
        return result 
    
    cover_wrapper.__signature__ = _mutmut_signature(xǁEventBookWǁcover_wrapper__mutmut_orig)
    xǁEventBookWǁcover_wrapper__mutmut_orig.__name__ = 'xǁEventBookWǁcover_wrapper'


class CommandBookW:
    """Wrapper for CommandBook proto with extension methods."""

    def xǁCommandBookWǁ__init____mutmut_orig(self, proto: CommandBook) -> None:
        self.proto = proto

    def xǁCommandBookWǁ__init____mutmut_1(self, proto: CommandBook) -> None:
        self.proto = None
    
    xǁCommandBookWǁ__init____mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁ__init____mutmut_1': xǁCommandBookWǁ__init____mutmut_1
    }
    
    def __init__(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁ__init____mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁ__init____mutmut_mutants"), args, kwargs, self)
        return result 
    
    __init__.__signature__ = _mutmut_signature(xǁCommandBookWǁ__init____mutmut_orig)
    xǁCommandBookWǁ__init____mutmut_orig.__name__ = 'xǁCommandBookWǁ__init__'

    def xǁCommandBookWǁpages__mutmut_orig(self) -> List["CommandPageW"]:
        """Return the command pages as wrapped CommandPageW instances."""
        return [CommandPageW(p) for p in self.proto.pages]

    def xǁCommandBookWǁpages__mutmut_1(self) -> List["CommandPageW"]:
        """Return the command pages as wrapped CommandPageW instances."""
        return [CommandPageW(None) for p in self.proto.pages]
    
    xǁCommandBookWǁpages__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁpages__mutmut_1': xǁCommandBookWǁpages__mutmut_1
    }
    
    def pages(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁpages__mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁpages__mutmut_mutants"), args, kwargs, self)
        return result 
    
    pages.__signature__ = _mutmut_signature(xǁCommandBookWǁpages__mutmut_orig)
    xǁCommandBookWǁpages__mutmut_orig.__name__ = 'xǁCommandBookWǁpages'

    def xǁCommandBookWǁ_cover__mutmut_orig(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("cover"):
            return None
        return self.proto.cover

    def xǁCommandBookWǁ_cover__mutmut_1(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if self.proto.HasField("cover"):
            return None
        return self.proto.cover

    def xǁCommandBookWǁ_cover__mutmut_2(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField(None):
            return None
        return self.proto.cover

    def xǁCommandBookWǁ_cover__mutmut_3(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("XXcoverXX"):
            return None
        return self.proto.cover

    def xǁCommandBookWǁ_cover__mutmut_4(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("COVER"):
            return None
        return self.proto.cover
    
    xǁCommandBookWǁ_cover__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁ_cover__mutmut_1': xǁCommandBookWǁ_cover__mutmut_1, 
        'xǁCommandBookWǁ_cover__mutmut_2': xǁCommandBookWǁ_cover__mutmut_2, 
        'xǁCommandBookWǁ_cover__mutmut_3': xǁCommandBookWǁ_cover__mutmut_3, 
        'xǁCommandBookWǁ_cover__mutmut_4': xǁCommandBookWǁ_cover__mutmut_4
    }
    
    def _cover(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁ_cover__mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁ_cover__mutmut_mutants"), args, kwargs, self)
        return result 
    
    _cover.__signature__ = _mutmut_signature(xǁCommandBookWǁ_cover__mutmut_orig)
    xǁCommandBookWǁ_cover__mutmut_orig.__name__ = 'xǁCommandBookWǁ_cover'

    def xǁCommandBookWǁdomain__mutmut_orig(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁCommandBookWǁdomain__mutmut_1(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = None
        if cover is None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁCommandBookWǁdomain__mutmut_2(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None and not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁCommandBookWǁdomain__mutmut_3(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is not None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁCommandBookWǁdomain__mutmut_4(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None or cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain
    
    xǁCommandBookWǁdomain__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁdomain__mutmut_1': xǁCommandBookWǁdomain__mutmut_1, 
        'xǁCommandBookWǁdomain__mutmut_2': xǁCommandBookWǁdomain__mutmut_2, 
        'xǁCommandBookWǁdomain__mutmut_3': xǁCommandBookWǁdomain__mutmut_3, 
        'xǁCommandBookWǁdomain__mutmut_4': xǁCommandBookWǁdomain__mutmut_4
    }
    
    def domain(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁdomain__mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁdomain__mutmut_mutants"), args, kwargs, self)
        return result 
    
    domain.__signature__ = _mutmut_signature(xǁCommandBookWǁdomain__mutmut_orig)
    xǁCommandBookWǁdomain__mutmut_orig.__name__ = 'xǁCommandBookWǁdomain'

    def xǁCommandBookWǁcorrelation_id__mutmut_orig(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is None:
            return ""
        return cover.correlation_id

    def xǁCommandBookWǁcorrelation_id__mutmut_1(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = None
        if cover is None:
            return ""
        return cover.correlation_id

    def xǁCommandBookWǁcorrelation_id__mutmut_2(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is not None:
            return ""
        return cover.correlation_id

    def xǁCommandBookWǁcorrelation_id__mutmut_3(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is None:
            return "XXXX"
        return cover.correlation_id
    
    xǁCommandBookWǁcorrelation_id__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁcorrelation_id__mutmut_1': xǁCommandBookWǁcorrelation_id__mutmut_1, 
        'xǁCommandBookWǁcorrelation_id__mutmut_2': xǁCommandBookWǁcorrelation_id__mutmut_2, 
        'xǁCommandBookWǁcorrelation_id__mutmut_3': xǁCommandBookWǁcorrelation_id__mutmut_3
    }
    
    def correlation_id(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁcorrelation_id__mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁcorrelation_id__mutmut_mutants"), args, kwargs, self)
        return result 
    
    correlation_id.__signature__ = _mutmut_signature(xǁCommandBookWǁcorrelation_id__mutmut_orig)
    xǁCommandBookWǁcorrelation_id__mutmut_orig.__name__ = 'xǁCommandBookWǁcorrelation_id'

    def xǁCommandBookWǁhas_correlation_id__mutmut_orig(self) -> bool:
        """Return True if the correlation_id is present and non-empty."""
        return bool(self.correlation_id())

    def xǁCommandBookWǁhas_correlation_id__mutmut_1(self) -> bool:
        """Return True if the correlation_id is present and non-empty."""
        return bool(None)
    
    xǁCommandBookWǁhas_correlation_id__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁhas_correlation_id__mutmut_1': xǁCommandBookWǁhas_correlation_id__mutmut_1
    }
    
    def has_correlation_id(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁhas_correlation_id__mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁhas_correlation_id__mutmut_mutants"), args, kwargs, self)
        return result 
    
    has_correlation_id.__signature__ = _mutmut_signature(xǁCommandBookWǁhas_correlation_id__mutmut_orig)
    xǁCommandBookWǁhas_correlation_id__mutmut_orig.__name__ = 'xǁCommandBookWǁhas_correlation_id'

    def xǁCommandBookWǁroot_uuid__mutmut_orig(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁCommandBookWǁroot_uuid__mutmut_1(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = None
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁCommandBookWǁroot_uuid__mutmut_2(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None and not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁCommandBookWǁroot_uuid__mutmut_3(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is not None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁCommandBookWǁroot_uuid__mutmut_4(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁCommandBookWǁroot_uuid__mutmut_5(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField(None):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁCommandBookWǁroot_uuid__mutmut_6(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("XXrootXX"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁCommandBookWǁroot_uuid__mutmut_7(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("ROOT"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁCommandBookWǁroot_uuid__mutmut_8(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=None)
        except ValueError:
            return None
    
    xǁCommandBookWǁroot_uuid__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁroot_uuid__mutmut_1': xǁCommandBookWǁroot_uuid__mutmut_1, 
        'xǁCommandBookWǁroot_uuid__mutmut_2': xǁCommandBookWǁroot_uuid__mutmut_2, 
        'xǁCommandBookWǁroot_uuid__mutmut_3': xǁCommandBookWǁroot_uuid__mutmut_3, 
        'xǁCommandBookWǁroot_uuid__mutmut_4': xǁCommandBookWǁroot_uuid__mutmut_4, 
        'xǁCommandBookWǁroot_uuid__mutmut_5': xǁCommandBookWǁroot_uuid__mutmut_5, 
        'xǁCommandBookWǁroot_uuid__mutmut_6': xǁCommandBookWǁroot_uuid__mutmut_6, 
        'xǁCommandBookWǁroot_uuid__mutmut_7': xǁCommandBookWǁroot_uuid__mutmut_7, 
        'xǁCommandBookWǁroot_uuid__mutmut_8': xǁCommandBookWǁroot_uuid__mutmut_8
    }
    
    def root_uuid(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁroot_uuid__mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁroot_uuid__mutmut_mutants"), args, kwargs, self)
        return result 
    
    root_uuid.__signature__ = _mutmut_signature(xǁCommandBookWǁroot_uuid__mutmut_orig)
    xǁCommandBookWǁroot_uuid__mutmut_orig.__name__ = 'xǁCommandBookWǁroot_uuid'

    def routing_key(self) -> str:
        """Compute the bus routing key."""
        return self.domain()

    def xǁCommandBookWǁcache_key__mutmut_orig(self) -> str:
        """Generate a cache key based on domain + root."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return f"{self.domain()}:"
        return f"{self.domain()}:{cover.root.value.hex()}"

    def xǁCommandBookWǁcache_key__mutmut_1(self) -> str:
        """Generate a cache key based on domain + root."""
        cover = None
        if cover is None or not cover.HasField("root"):
            return f"{self.domain()}:"
        return f"{self.domain()}:{cover.root.value.hex()}"

    def xǁCommandBookWǁcache_key__mutmut_2(self) -> str:
        """Generate a cache key based on domain + root."""
        cover = self._cover()
        if cover is None and not cover.HasField("root"):
            return f"{self.domain()}:"
        return f"{self.domain()}:{cover.root.value.hex()}"

    def xǁCommandBookWǁcache_key__mutmut_3(self) -> str:
        """Generate a cache key based on domain + root."""
        cover = self._cover()
        if cover is not None or not cover.HasField("root"):
            return f"{self.domain()}:"
        return f"{self.domain()}:{cover.root.value.hex()}"

    def xǁCommandBookWǁcache_key__mutmut_4(self) -> str:
        """Generate a cache key based on domain + root."""
        cover = self._cover()
        if cover is None or cover.HasField("root"):
            return f"{self.domain()}:"
        return f"{self.domain()}:{cover.root.value.hex()}"

    def xǁCommandBookWǁcache_key__mutmut_5(self) -> str:
        """Generate a cache key based on domain + root."""
        cover = self._cover()
        if cover is None or not cover.HasField(None):
            return f"{self.domain()}:"
        return f"{self.domain()}:{cover.root.value.hex()}"

    def xǁCommandBookWǁcache_key__mutmut_6(self) -> str:
        """Generate a cache key based on domain + root."""
        cover = self._cover()
        if cover is None or not cover.HasField("XXrootXX"):
            return f"{self.domain()}:"
        return f"{self.domain()}:{cover.root.value.hex()}"

    def xǁCommandBookWǁcache_key__mutmut_7(self) -> str:
        """Generate a cache key based on domain + root."""
        cover = self._cover()
        if cover is None or not cover.HasField("ROOT"):
            return f"{self.domain()}:"
        return f"{self.domain()}:{cover.root.value.hex()}"
    
    xǁCommandBookWǁcache_key__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁcache_key__mutmut_1': xǁCommandBookWǁcache_key__mutmut_1, 
        'xǁCommandBookWǁcache_key__mutmut_2': xǁCommandBookWǁcache_key__mutmut_2, 
        'xǁCommandBookWǁcache_key__mutmut_3': xǁCommandBookWǁcache_key__mutmut_3, 
        'xǁCommandBookWǁcache_key__mutmut_4': xǁCommandBookWǁcache_key__mutmut_4, 
        'xǁCommandBookWǁcache_key__mutmut_5': xǁCommandBookWǁcache_key__mutmut_5, 
        'xǁCommandBookWǁcache_key__mutmut_6': xǁCommandBookWǁcache_key__mutmut_6, 
        'xǁCommandBookWǁcache_key__mutmut_7': xǁCommandBookWǁcache_key__mutmut_7
    }
    
    def cache_key(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁcache_key__mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁcache_key__mutmut_mutants"), args, kwargs, self)
        return result 
    
    cache_key.__signature__ = _mutmut_signature(xǁCommandBookWǁcache_key__mutmut_orig)
    xǁCommandBookWǁcache_key__mutmut_orig.__name__ = 'xǁCommandBookWǁcache_key'

    def xǁCommandBookWǁcover_wrapper__mutmut_orig(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁCommandBookWǁcover_wrapper__mutmut_1(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = None
        if cover is None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁCommandBookWǁcover_wrapper__mutmut_2(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is not None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁCommandBookWǁcover_wrapper__mutmut_3(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(None)
        return CoverW(cover)

    def xǁCommandBookWǁcover_wrapper__mutmut_4(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(Cover())
        return CoverW(None)
    
    xǁCommandBookWǁcover_wrapper__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandBookWǁcover_wrapper__mutmut_1': xǁCommandBookWǁcover_wrapper__mutmut_1, 
        'xǁCommandBookWǁcover_wrapper__mutmut_2': xǁCommandBookWǁcover_wrapper__mutmut_2, 
        'xǁCommandBookWǁcover_wrapper__mutmut_3': xǁCommandBookWǁcover_wrapper__mutmut_3, 
        'xǁCommandBookWǁcover_wrapper__mutmut_4': xǁCommandBookWǁcover_wrapper__mutmut_4
    }
    
    def cover_wrapper(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandBookWǁcover_wrapper__mutmut_orig"), object.__getattribute__(self, "xǁCommandBookWǁcover_wrapper__mutmut_mutants"), args, kwargs, self)
        return result 
    
    cover_wrapper.__signature__ = _mutmut_signature(xǁCommandBookWǁcover_wrapper__mutmut_orig)
    xǁCommandBookWǁcover_wrapper__mutmut_orig.__name__ = 'xǁCommandBookWǁcover_wrapper'


class QueryW:
    """Wrapper for Query proto with extension methods."""

    def xǁQueryWǁ__init____mutmut_orig(self, proto: Query) -> None:
        self.proto = proto

    def xǁQueryWǁ__init____mutmut_1(self, proto: Query) -> None:
        self.proto = None
    
    xǁQueryWǁ__init____mutmut_mutants : ClassVar[MutantDict] = {
    'xǁQueryWǁ__init____mutmut_1': xǁQueryWǁ__init____mutmut_1
    }
    
    def __init__(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁQueryWǁ__init____mutmut_orig"), object.__getattribute__(self, "xǁQueryWǁ__init____mutmut_mutants"), args, kwargs, self)
        return result 
    
    __init__.__signature__ = _mutmut_signature(xǁQueryWǁ__init____mutmut_orig)
    xǁQueryWǁ__init____mutmut_orig.__name__ = 'xǁQueryWǁ__init__'

    def xǁQueryWǁ_cover__mutmut_orig(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("cover"):
            return None
        return self.proto.cover

    def xǁQueryWǁ_cover__mutmut_1(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if self.proto.HasField("cover"):
            return None
        return self.proto.cover

    def xǁQueryWǁ_cover__mutmut_2(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField(None):
            return None
        return self.proto.cover

    def xǁQueryWǁ_cover__mutmut_3(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("XXcoverXX"):
            return None
        return self.proto.cover

    def xǁQueryWǁ_cover__mutmut_4(self) -> Optional[Cover]:
        """Get the cover, or None if not set."""
        if not self.proto.HasField("COVER"):
            return None
        return self.proto.cover
    
    xǁQueryWǁ_cover__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁQueryWǁ_cover__mutmut_1': xǁQueryWǁ_cover__mutmut_1, 
        'xǁQueryWǁ_cover__mutmut_2': xǁQueryWǁ_cover__mutmut_2, 
        'xǁQueryWǁ_cover__mutmut_3': xǁQueryWǁ_cover__mutmut_3, 
        'xǁQueryWǁ_cover__mutmut_4': xǁQueryWǁ_cover__mutmut_4
    }
    
    def _cover(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁQueryWǁ_cover__mutmut_orig"), object.__getattribute__(self, "xǁQueryWǁ_cover__mutmut_mutants"), args, kwargs, self)
        return result 
    
    _cover.__signature__ = _mutmut_signature(xǁQueryWǁ_cover__mutmut_orig)
    xǁQueryWǁ_cover__mutmut_orig.__name__ = 'xǁQueryWǁ_cover'

    def xǁQueryWǁdomain__mutmut_orig(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁQueryWǁdomain__mutmut_1(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = None
        if cover is None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁQueryWǁdomain__mutmut_2(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None and not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁQueryWǁdomain__mutmut_3(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is not None or not cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain

    def xǁQueryWǁdomain__mutmut_4(self) -> str:
        """Get the domain from the cover, or UNKNOWN_DOMAIN if missing."""
        cover = self._cover()
        if cover is None or cover.domain:
            return UNKNOWN_DOMAIN
        return cover.domain
    
    xǁQueryWǁdomain__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁQueryWǁdomain__mutmut_1': xǁQueryWǁdomain__mutmut_1, 
        'xǁQueryWǁdomain__mutmut_2': xǁQueryWǁdomain__mutmut_2, 
        'xǁQueryWǁdomain__mutmut_3': xǁQueryWǁdomain__mutmut_3, 
        'xǁQueryWǁdomain__mutmut_4': xǁQueryWǁdomain__mutmut_4
    }
    
    def domain(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁQueryWǁdomain__mutmut_orig"), object.__getattribute__(self, "xǁQueryWǁdomain__mutmut_mutants"), args, kwargs, self)
        return result 
    
    domain.__signature__ = _mutmut_signature(xǁQueryWǁdomain__mutmut_orig)
    xǁQueryWǁdomain__mutmut_orig.__name__ = 'xǁQueryWǁdomain'

    def xǁQueryWǁcorrelation_id__mutmut_orig(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is None:
            return ""
        return cover.correlation_id

    def xǁQueryWǁcorrelation_id__mutmut_1(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = None
        if cover is None:
            return ""
        return cover.correlation_id

    def xǁQueryWǁcorrelation_id__mutmut_2(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is not None:
            return ""
        return cover.correlation_id

    def xǁQueryWǁcorrelation_id__mutmut_3(self) -> str:
        """Get the correlation_id from the cover, or empty string if missing."""
        cover = self._cover()
        if cover is None:
            return "XXXX"
        return cover.correlation_id
    
    xǁQueryWǁcorrelation_id__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁQueryWǁcorrelation_id__mutmut_1': xǁQueryWǁcorrelation_id__mutmut_1, 
        'xǁQueryWǁcorrelation_id__mutmut_2': xǁQueryWǁcorrelation_id__mutmut_2, 
        'xǁQueryWǁcorrelation_id__mutmut_3': xǁQueryWǁcorrelation_id__mutmut_3
    }
    
    def correlation_id(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁQueryWǁcorrelation_id__mutmut_orig"), object.__getattribute__(self, "xǁQueryWǁcorrelation_id__mutmut_mutants"), args, kwargs, self)
        return result 
    
    correlation_id.__signature__ = _mutmut_signature(xǁQueryWǁcorrelation_id__mutmut_orig)
    xǁQueryWǁcorrelation_id__mutmut_orig.__name__ = 'xǁQueryWǁcorrelation_id'

    def xǁQueryWǁhas_correlation_id__mutmut_orig(self) -> bool:
        """Return True if the correlation_id is present and non-empty."""
        return bool(self.correlation_id())

    def xǁQueryWǁhas_correlation_id__mutmut_1(self) -> bool:
        """Return True if the correlation_id is present and non-empty."""
        return bool(None)
    
    xǁQueryWǁhas_correlation_id__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁQueryWǁhas_correlation_id__mutmut_1': xǁQueryWǁhas_correlation_id__mutmut_1
    }
    
    def has_correlation_id(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁQueryWǁhas_correlation_id__mutmut_orig"), object.__getattribute__(self, "xǁQueryWǁhas_correlation_id__mutmut_mutants"), args, kwargs, self)
        return result 
    
    has_correlation_id.__signature__ = _mutmut_signature(xǁQueryWǁhas_correlation_id__mutmut_orig)
    xǁQueryWǁhas_correlation_id__mutmut_orig.__name__ = 'xǁQueryWǁhas_correlation_id'

    def xǁQueryWǁroot_uuid__mutmut_orig(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁQueryWǁroot_uuid__mutmut_1(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = None
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁQueryWǁroot_uuid__mutmut_2(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None and not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁQueryWǁroot_uuid__mutmut_3(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is not None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁQueryWǁroot_uuid__mutmut_4(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁQueryWǁroot_uuid__mutmut_5(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField(None):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁQueryWǁroot_uuid__mutmut_6(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("XXrootXX"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁQueryWǁroot_uuid__mutmut_7(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("ROOT"):
            return None
        try:
            return PyUUID(bytes=cover.root.value)
        except ValueError:
            return None

    def xǁQueryWǁroot_uuid__mutmut_8(self) -> Optional[PyUUID]:
        """Extract the root UUID from the cover."""
        cover = self._cover()
        if cover is None or not cover.HasField("root"):
            return None
        try:
            return PyUUID(bytes=None)
        except ValueError:
            return None
    
    xǁQueryWǁroot_uuid__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁQueryWǁroot_uuid__mutmut_1': xǁQueryWǁroot_uuid__mutmut_1, 
        'xǁQueryWǁroot_uuid__mutmut_2': xǁQueryWǁroot_uuid__mutmut_2, 
        'xǁQueryWǁroot_uuid__mutmut_3': xǁQueryWǁroot_uuid__mutmut_3, 
        'xǁQueryWǁroot_uuid__mutmut_4': xǁQueryWǁroot_uuid__mutmut_4, 
        'xǁQueryWǁroot_uuid__mutmut_5': xǁQueryWǁroot_uuid__mutmut_5, 
        'xǁQueryWǁroot_uuid__mutmut_6': xǁQueryWǁroot_uuid__mutmut_6, 
        'xǁQueryWǁroot_uuid__mutmut_7': xǁQueryWǁroot_uuid__mutmut_7, 
        'xǁQueryWǁroot_uuid__mutmut_8': xǁQueryWǁroot_uuid__mutmut_8
    }
    
    def root_uuid(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁQueryWǁroot_uuid__mutmut_orig"), object.__getattribute__(self, "xǁQueryWǁroot_uuid__mutmut_mutants"), args, kwargs, self)
        return result 
    
    root_uuid.__signature__ = _mutmut_signature(xǁQueryWǁroot_uuid__mutmut_orig)
    xǁQueryWǁroot_uuid__mutmut_orig.__name__ = 'xǁQueryWǁroot_uuid'

    def routing_key(self) -> str:
        """Compute the bus routing key."""
        return self.domain()

    def xǁQueryWǁcover_wrapper__mutmut_orig(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁQueryWǁcover_wrapper__mutmut_1(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = None
        if cover is None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁQueryWǁcover_wrapper__mutmut_2(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is not None:
            return CoverW(Cover())
        return CoverW(cover)

    def xǁQueryWǁcover_wrapper__mutmut_3(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(None)
        return CoverW(cover)

    def xǁQueryWǁcover_wrapper__mutmut_4(self) -> "CoverW":
        """Return a CoverW wrapping the cover."""
        cover = self._cover()
        if cover is None:
            return CoverW(Cover())
        return CoverW(None)
    
    xǁQueryWǁcover_wrapper__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁQueryWǁcover_wrapper__mutmut_1': xǁQueryWǁcover_wrapper__mutmut_1, 
        'xǁQueryWǁcover_wrapper__mutmut_2': xǁQueryWǁcover_wrapper__mutmut_2, 
        'xǁQueryWǁcover_wrapper__mutmut_3': xǁQueryWǁcover_wrapper__mutmut_3, 
        'xǁQueryWǁcover_wrapper__mutmut_4': xǁQueryWǁcover_wrapper__mutmut_4
    }
    
    def cover_wrapper(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁQueryWǁcover_wrapper__mutmut_orig"), object.__getattribute__(self, "xǁQueryWǁcover_wrapper__mutmut_mutants"), args, kwargs, self)
        return result 
    
    cover_wrapper.__signature__ = _mutmut_signature(xǁQueryWǁcover_wrapper__mutmut_orig)
    xǁQueryWǁcover_wrapper__mutmut_orig.__name__ = 'xǁQueryWǁcover_wrapper'


class EventPageW:
    """Wrapper for EventPage proto with extension methods."""

    def xǁEventPageWǁ__init____mutmut_orig(self, proto: EventPage) -> None:
        self.proto = proto

    def xǁEventPageWǁ__init____mutmut_1(self, proto: EventPage) -> None:
        self.proto = None
    
    xǁEventPageWǁ__init____mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventPageWǁ__init____mutmut_1': xǁEventPageWǁ__init____mutmut_1
    }
    
    def __init__(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventPageWǁ__init____mutmut_orig"), object.__getattribute__(self, "xǁEventPageWǁ__init____mutmut_mutants"), args, kwargs, self)
        return result 
    
    __init__.__signature__ = _mutmut_signature(xǁEventPageWǁ__init____mutmut_orig)
    xǁEventPageWǁ__init____mutmut_orig.__name__ = 'xǁEventPageWǁ__init__'

    def xǁEventPageWǁdecode_event__mutmut_orig(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("event"):
            return None
        if not type_url_matches(self.proto.event.type_url, type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_1(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if self.proto.HasField("event"):
            return None
        if not type_url_matches(self.proto.event.type_url, type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_2(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField(None):
            return None
        if not type_url_matches(self.proto.event.type_url, type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_3(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("XXeventXX"):
            return None
        if not type_url_matches(self.proto.event.type_url, type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_4(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("EVENT"):
            return None
        if not type_url_matches(self.proto.event.type_url, type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_5(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("event"):
            return None
        if type_url_matches(self.proto.event.type_url, type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_6(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("event"):
            return None
        if not type_url_matches(None, type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_7(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("event"):
            return None
        if not type_url_matches(self.proto.event.type_url, None):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_8(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("event"):
            return None
        if not type_url_matches(type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_9(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("event"):
            return None
        if not type_url_matches(self.proto.event.type_url, ):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_10(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("event"):
            return None
        if not type_url_matches(self.proto.event.type_url, type_suffix):
            return None
        try:
            msg = None
            self.proto.event.Unpack(msg)
            return msg
        except Exception:
            return None

    def xǁEventPageWǁdecode_event__mutmut_11(self, type_suffix: str, msg_class: Type[T]) -> Optional[T]:
        """Attempt to decode an event payload if the type URL matches.

        Args:
            type_suffix: The expected type URL suffix
            msg_class: The protobuf message class to decode into

        Returns:
            The decoded message if type matches and decoding succeeds, None otherwise
        """
        if not self.proto.HasField("event"):
            return None
        if not type_url_matches(self.proto.event.type_url, type_suffix):
            return None
        try:
            msg = msg_class()
            self.proto.event.Unpack(None)
            return msg
        except Exception:
            return None
    
    xǁEventPageWǁdecode_event__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁEventPageWǁdecode_event__mutmut_1': xǁEventPageWǁdecode_event__mutmut_1, 
        'xǁEventPageWǁdecode_event__mutmut_2': xǁEventPageWǁdecode_event__mutmut_2, 
        'xǁEventPageWǁdecode_event__mutmut_3': xǁEventPageWǁdecode_event__mutmut_3, 
        'xǁEventPageWǁdecode_event__mutmut_4': xǁEventPageWǁdecode_event__mutmut_4, 
        'xǁEventPageWǁdecode_event__mutmut_5': xǁEventPageWǁdecode_event__mutmut_5, 
        'xǁEventPageWǁdecode_event__mutmut_6': xǁEventPageWǁdecode_event__mutmut_6, 
        'xǁEventPageWǁdecode_event__mutmut_7': xǁEventPageWǁdecode_event__mutmut_7, 
        'xǁEventPageWǁdecode_event__mutmut_8': xǁEventPageWǁdecode_event__mutmut_8, 
        'xǁEventPageWǁdecode_event__mutmut_9': xǁEventPageWǁdecode_event__mutmut_9, 
        'xǁEventPageWǁdecode_event__mutmut_10': xǁEventPageWǁdecode_event__mutmut_10, 
        'xǁEventPageWǁdecode_event__mutmut_11': xǁEventPageWǁdecode_event__mutmut_11
    }
    
    def decode_event(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁEventPageWǁdecode_event__mutmut_orig"), object.__getattribute__(self, "xǁEventPageWǁdecode_event__mutmut_mutants"), args, kwargs, self)
        return result 
    
    decode_event.__signature__ = _mutmut_signature(xǁEventPageWǁdecode_event__mutmut_orig)
    xǁEventPageWǁdecode_event__mutmut_orig.__name__ = 'xǁEventPageWǁdecode_event'


class CommandPageW:
    """Wrapper for CommandPage proto with extension methods."""

    def xǁCommandPageWǁ__init____mutmut_orig(self, proto: CommandPage) -> None:
        self.proto = proto

    def xǁCommandPageWǁ__init____mutmut_1(self, proto: CommandPage) -> None:
        self.proto = None
    
    xǁCommandPageWǁ__init____mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandPageWǁ__init____mutmut_1': xǁCommandPageWǁ__init____mutmut_1
    }
    
    def __init__(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandPageWǁ__init____mutmut_orig"), object.__getattribute__(self, "xǁCommandPageWǁ__init____mutmut_mutants"), args, kwargs, self)
        return result 
    
    __init__.__signature__ = _mutmut_signature(xǁCommandPageWǁ__init____mutmut_orig)
    xǁCommandPageWǁ__init____mutmut_orig.__name__ = 'xǁCommandPageWǁ__init__'

    def sequence(self) -> int:
        """Return the sequence number."""
        return self.proto.sequence


class CommandResponseW:
    """Wrapper for CommandResponse proto with extension methods."""

    def xǁCommandResponseWǁ__init____mutmut_orig(self, proto: CommandResponse) -> None:
        self.proto = proto

    def xǁCommandResponseWǁ__init____mutmut_1(self, proto: CommandResponse) -> None:
        self.proto = None
    
    xǁCommandResponseWǁ__init____mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandResponseWǁ__init____mutmut_1': xǁCommandResponseWǁ__init____mutmut_1
    }
    
    def __init__(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandResponseWǁ__init____mutmut_orig"), object.__getattribute__(self, "xǁCommandResponseWǁ__init____mutmut_mutants"), args, kwargs, self)
        return result 
    
    __init__.__signature__ = _mutmut_signature(xǁCommandResponseWǁ__init____mutmut_orig)
    xǁCommandResponseWǁ__init____mutmut_orig.__name__ = 'xǁCommandResponseWǁ__init__'

    def xǁCommandResponseWǁevents_book__mutmut_orig(self) -> Optional["EventBookW"]:
        """Return the events as a wrapped EventBookW, or None if not set."""
        if not self.proto.HasField("events"):
            return None
        return EventBookW(self.proto.events)

    def xǁCommandResponseWǁevents_book__mutmut_1(self) -> Optional["EventBookW"]:
        """Return the events as a wrapped EventBookW, or None if not set."""
        if self.proto.HasField("events"):
            return None
        return EventBookW(self.proto.events)

    def xǁCommandResponseWǁevents_book__mutmut_2(self) -> Optional["EventBookW"]:
        """Return the events as a wrapped EventBookW, or None if not set."""
        if not self.proto.HasField(None):
            return None
        return EventBookW(self.proto.events)

    def xǁCommandResponseWǁevents_book__mutmut_3(self) -> Optional["EventBookW"]:
        """Return the events as a wrapped EventBookW, or None if not set."""
        if not self.proto.HasField("XXeventsXX"):
            return None
        return EventBookW(self.proto.events)

    def xǁCommandResponseWǁevents_book__mutmut_4(self) -> Optional["EventBookW"]:
        """Return the events as a wrapped EventBookW, or None if not set."""
        if not self.proto.HasField("EVENTS"):
            return None
        return EventBookW(self.proto.events)

    def xǁCommandResponseWǁevents_book__mutmut_5(self) -> Optional["EventBookW"]:
        """Return the events as a wrapped EventBookW, or None if not set."""
        if not self.proto.HasField("events"):
            return None
        return EventBookW(None)
    
    xǁCommandResponseWǁevents_book__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandResponseWǁevents_book__mutmut_1': xǁCommandResponseWǁevents_book__mutmut_1, 
        'xǁCommandResponseWǁevents_book__mutmut_2': xǁCommandResponseWǁevents_book__mutmut_2, 
        'xǁCommandResponseWǁevents_book__mutmut_3': xǁCommandResponseWǁevents_book__mutmut_3, 
        'xǁCommandResponseWǁevents_book__mutmut_4': xǁCommandResponseWǁevents_book__mutmut_4, 
        'xǁCommandResponseWǁevents_book__mutmut_5': xǁCommandResponseWǁevents_book__mutmut_5
    }
    
    def events_book(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandResponseWǁevents_book__mutmut_orig"), object.__getattribute__(self, "xǁCommandResponseWǁevents_book__mutmut_mutants"), args, kwargs, self)
        return result 
    
    events_book.__signature__ = _mutmut_signature(xǁCommandResponseWǁevents_book__mutmut_orig)
    xǁCommandResponseWǁevents_book__mutmut_orig.__name__ = 'xǁCommandResponseWǁevents_book'

    def xǁCommandResponseWǁevents__mutmut_orig(self) -> List["EventPageW"]:
        """Extract the event pages as wrapped EventPageW instances."""
        if not self.proto.HasField("events"):
            return []
        return [EventPageW(p) for p in self.proto.events.pages]

    def xǁCommandResponseWǁevents__mutmut_1(self) -> List["EventPageW"]:
        """Extract the event pages as wrapped EventPageW instances."""
        if self.proto.HasField("events"):
            return []
        return [EventPageW(p) for p in self.proto.events.pages]

    def xǁCommandResponseWǁevents__mutmut_2(self) -> List["EventPageW"]:
        """Extract the event pages as wrapped EventPageW instances."""
        if not self.proto.HasField(None):
            return []
        return [EventPageW(p) for p in self.proto.events.pages]

    def xǁCommandResponseWǁevents__mutmut_3(self) -> List["EventPageW"]:
        """Extract the event pages as wrapped EventPageW instances."""
        if not self.proto.HasField("XXeventsXX"):
            return []
        return [EventPageW(p) for p in self.proto.events.pages]

    def xǁCommandResponseWǁevents__mutmut_4(self) -> List["EventPageW"]:
        """Extract the event pages as wrapped EventPageW instances."""
        if not self.proto.HasField("EVENTS"):
            return []
        return [EventPageW(p) for p in self.proto.events.pages]

    def xǁCommandResponseWǁevents__mutmut_5(self) -> List["EventPageW"]:
        """Extract the event pages as wrapped EventPageW instances."""
        if not self.proto.HasField("events"):
            return []
        return [EventPageW(None) for p in self.proto.events.pages]
    
    xǁCommandResponseWǁevents__mutmut_mutants : ClassVar[MutantDict] = {
    'xǁCommandResponseWǁevents__mutmut_1': xǁCommandResponseWǁevents__mutmut_1, 
        'xǁCommandResponseWǁevents__mutmut_2': xǁCommandResponseWǁevents__mutmut_2, 
        'xǁCommandResponseWǁevents__mutmut_3': xǁCommandResponseWǁevents__mutmut_3, 
        'xǁCommandResponseWǁevents__mutmut_4': xǁCommandResponseWǁevents__mutmut_4, 
        'xǁCommandResponseWǁevents__mutmut_5': xǁCommandResponseWǁevents__mutmut_5
    }
    
    def events(self, *args, **kwargs):
        result = _mutmut_trampoline(object.__getattribute__(self, "xǁCommandResponseWǁevents__mutmut_orig"), object.__getattribute__(self, "xǁCommandResponseWǁevents__mutmut_mutants"), args, kwargs, self)
        return result 
    
    events.__signature__ = _mutmut_signature(xǁCommandResponseWǁevents__mutmut_orig)
    xǁCommandResponseWǁevents__mutmut_orig.__name__ = 'xǁCommandResponseWǁevents'



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/fulfillment.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'examples/fulfillment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from examples import order_pb2 as examples_dot_order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65xamples/fulfillment.proto\x12\x08\x65xamples\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14\x65xamples/order.proto\"U\n\x0e\x43reateShipment\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x12.examples.LineItemR\x05items\")\n\nMarkPicked\x12\x1b\n\tpicker_id\x18\x01 \x01(\tR\x08pickerId\")\n\nMarkPacked\x12\x1b\n\tpacker_id\x18\x01 \x01(\tR\x08packerId\"I\n\x04Ship\x12\x18\n\x07\x63\x61rrier\x18\x01 \x01(\tR\x07\x63\x61rrier\x12\'\n\x0ftracking_number\x18\x02 \x01(\tR\x0etrackingNumber\".\n\x0eRecordDelivery\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature\"\xa9\x01\n\x0fShipmentCreated\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12\x16\n\x06status\x18\x02 \x01(\tR\x06status\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12(\n\x05items\x18\x04 \x03(\x0b\x32\x12.examples.LineItemR\x05items\"c\n\x0bItemsPicked\x12\x1b\n\tpicker_id\x18\x01 \x01(\tR\x08pickerId\x12\x37\n\tpicked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08pickedAt\"c\n\x0bItemsPacked\x12\x1b\n\tpacker_id\x18\x01 \x01(\tR\x08packerId\x12\x37\n\tpacked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08packedAt\"\xcc\x01\n\x07Shipped\x12\x18\n\x07\x63\x61rrier\x18\x01 \x01(\tR\x07\x63\x61rrier\x12\'\n\x0ftracking_number\x18\x02 \x01(\tR\x0etrackingNumber\x12\x39\n\nshipped_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tshippedAt\x12(\n\x05items\x18\x04 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12\x19\n\x08order_id\x18\x05 \x01(\tR\x07orderId\"h\n\tDelivered\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature\x12=\n\x0c\x64\x65livered_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x64\x65liveredAt\"\x8a\x02\n\x10\x46ulfillmentState\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12\x16\n\x06status\x18\x02 \x01(\tR\x06status\x12\'\n\x0ftracking_number\x18\x03 \x01(\tR\x0etrackingNumber\x12\x18\n\x07\x63\x61rrier\x18\x04 \x01(\tR\x07\x63\x61rrier\x12\x1b\n\tpicker_id\x18\x05 \x01(\tR\x08pickerId\x12\x1b\n\tpacker_id\x18\x06 \x01(\tR\x08packerId\x12\x1c\n\tsignature\x18\x07 \x01(\tR\tsignature\x12(\n\x05items\x18\x08 \x03(\x0b\x32\x12.examples.LineItemR\x05itemsB\x94\x01\n\x0c\x63om.examplesB\x10\x46ulfillmentProtoP\x01Z2github.com/angzarr/angzarr/proto/examples;examples\xa2\x02\x03\x45XX\xaa\x02\x08\x45xamples\xca\x02\x08\x45xamples\xe2\x02\x14\x45xamples\\GPBMetadata\xea\x02\x08\x45xamplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.fulfillment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.examplesB\020FulfillmentProtoP\001Z2github.com/angzarr/angzarr/proto/examples;examples\242\002\003EXX\252\002\010Examples\312\002\010Examples\342\002\024Examples\\GPBMetadata\352\002\010Examples'
  _globals['_CREATESHIPMENT']._serialized_start=95
  _globals['_CREATESHIPMENT']._serialized_end=180
  _globals['_MARKPICKED']._serialized_start=182
  _globals['_MARKPICKED']._serialized_end=223
  _globals['_MARKPACKED']._serialized_start=225
  _globals['_MARKPACKED']._serialized_end=266
  _globals['_SHIP']._serialized_start=268
  _globals['_SHIP']._serialized_end=341
  _globals['_RECORDDELIVERY']._serialized_start=343
  _globals['_RECORDDELIVERY']._serialized_end=389
  _globals['_SHIPMENTCREATED']._serialized_start=392
  _globals['_SHIPMENTCREATED']._serialized_end=561
  _globals['_ITEMSPICKED']._serialized_start=563
  _globals['_ITEMSPICKED']._serialized_end=662
  _globals['_ITEMSPACKED']._serialized_start=664
  _globals['_ITEMSPACKED']._serialized_end=763
  _globals['_SHIPPED']._serialized_start=766
  _globals['_SHIPPED']._serialized_end=970
  _globals['_DELIVERED']._serialized_start=972
  _globals['_DELIVERED']._serialized_end=1076
  _globals['_FULFILLMENTSTATE']._serialized_start=1079
  _globals['_FULFILLMENTSTATE']._serialized_end=1345
# @@protoc_insertion_point(module_scope)



"""Helper functions for working with Angzarr proto types."""

from datetime import datetime
from typing import Optional, Union
from uuid import UUID as PyUUID

from google.protobuf.timestamp_pb2 import Timestamp
from google.protobuf.any_pb2 import Any as ProtoAny

from .proto.angzarr import (
    UUID,
    Cover,
    Edition,
    DomainDivergence,
    EventBook,
    CommandBook,
    Query,
    EventPage,
    CommandPage,
    SequenceRange,
    TemporalQuery,
)
from .errors import InvalidTimestampError

# Constants matching Rust proto_ext::constants
UNKNOWN_DOMAIN = "unknown"
WILDCARD_DOMAIN = "*"
DEFAULT_EDITION = "angzarr"
META_ANGZARR_DOMAIN = "_angzarr"
PROJECTION_DOMAIN_PREFIX = "projection:"
CORRELATION_ID_HEADER = "x-correlation-id"
TYPE_URL_PREFIX = "type.googleapis.com/"


# Type for Cover-bearing objects
CoverBearer = Union[EventBook, CommandBook, Query, Cover]


def cover_of(obj: CoverBearer) -> Optional[Cover]:
    """Extract the Cover from various proto types."""
    if isinstance(obj, Cover):
        return obj
    if hasattr(obj, "cover"):
        return obj.cover
    return None


def domain(obj: CoverBearer) -> str:
    """Get the domain from a Cover-bearing type, or UNKNOWN_DOMAIN if missing."""
    c = cover_of(obj)
    if c is None or not c.domain:
        return UNKNOWN_DOMAIN
    return c.domain


def correlation_id(obj: CoverBearer) -> str:
    """Get the correlation_id from a Cover-bearing type, or empty string if missing."""
    c = cover_of(obj)
    if c is None:
        return ""
    return c.correlation_id


def has_correlation_id(obj: CoverBearer) -> bool:
    """Return True if the correlation_id is present and non-empty."""
    return bool(correlation_id(obj))


def root_uuid(obj: CoverBearer) -> Optional[PyUUID]:
    """Extract the root UUID from a Cover-bearing type."""
    c = cover_of(obj)
    if c is None or not c.HasField("root"):
        return None
    try:
        return PyUUID(bytes=c.root.value)
    except ValueError:
        return None


def root_id_hex(obj: CoverBearer) -> str:
    """Return the root UUID as a hex string, or empty string if missing."""
    c = cover_of(obj)
    if c is None or not c.HasField("root"):
        return ""
    return c.root.value.hex()


def edition(obj: CoverBearer) -> str:
    """Return the edition name from a Cover-bearing type, defaulting to DEFAULT_EDITION."""
    c = cover_of(obj)
    if c is None or not c.HasField("edition") or not c.edition.name:
        return DEFAULT_EDITION
    return c.edition.name


def edition_opt(obj: CoverBearer) -> Optional[str]:
    """Return the edition name as Optional, None if not set."""
    c = cover_of(obj)
    if c is None or not c.HasField("edition") or not c.edition.name:
        return None
    return c.edition.name


def routing_key(obj: CoverBearer) -> str:
    """Compute the bus routing key for a Cover-bearing type."""
    return domain(obj)


def cache_key(obj: CoverBearer) -> str:
    """Generate a cache key based on domain + root."""
    return f"{domain(obj)}:{root_id_hex(obj)}"


# UUID conversion


def uuid_to_proto(u: PyUUID) -> UUID:
    """Convert a Python UUID to a proto UUID."""
    return UUID(value=u.bytes)


def proto_to_uuid(u: UUID) -> PyUUID:
    """Convert a proto UUID to Python UUID."""
    return PyUUID(bytes=u.value)


# Edition helpers


def main_timeline() -> Edition:
    """Return an Edition representing the main timeline."""
    return Edition(name=DEFAULT_EDITION)


def implicit_edition(name: str) -> Edition:
    """Create an edition with the given name but no divergences."""
    return Edition(name=name)


def explicit_edition(name: str, divergences: list[DomainDivergence]) -> Edition:
    """Create an edition with divergence points."""
    return Edition(name=name, divergences=divergences)


def is_main_timeline(e: Optional[Edition]) -> bool:
    """Check if an edition represents the main timeline."""
    return e is None or not e.name or e.name == DEFAULT_EDITION


def divergence_for(e: Optional[Edition], domain_name: str) -> int:
    """Return the divergence sequence for a domain, or -1 if not found."""
    if e is None:
        return -1
    for d in e.divergences:
        if d.domain == domain_name:
            return d.sequence
    return -1


# EventBook helpers


def next_sequence(book: EventBook) -> int:
    """Return the next sequence number from an EventBook.

    The framework computes this value on load.
    """
    if book is None:
        return 0
    return book.next_sequence


def event_pages(book: Optional[EventBook]) -> list[EventPage]:
    """Return the event pages from an EventBook, or empty list if None."""
    if book is None:
        return []
    return list(book.pages)


# CommandBook helpers


def command_pages(book: Optional[CommandBook]) -> list[CommandPage]:
    """Return the command pages from a CommandBook, or empty list if None."""
    if book is None:
        return []
    return list(book.pages)


# CommandResponse helpers


def events_from_response(resp) -> list[EventPage]:
    """Extract the event pages from a CommandResponse."""
    if resp is None or not resp.HasField("events"):
        return []
    return list(resp.events.pages)


# Type URL helpers


def type_url(package_name: str, type_name: str) -> str:
    """Construct a full type URL from a package and type name."""
    return f"{TYPE_URL_PREFIX}{package_name}.{type_name}"


def type_name_from_url(type_url_str: str) -> str:
    """Extract the type name from a type URL."""
    if "." in type_url_str:
        return type_url_str.rsplit(".", 1)[1]
    if "/" in type_url_str:
        return type_url_str.rsplit("/", 1)[1]
    return type_url_str


def type_url_matches(type_url_str: str, suffix: str) -> bool:
    """Check if a type URL ends with the given suffix."""
    return type_url_str.endswith(suffix)


# Timestamp helpers


def now() -> Timestamp:
    """Return the current time as a protobuf Timestamp."""
    ts = Timestamp()
    ts.GetCurrentTime()
    return ts


def parse_timestamp(rfc3339: str) -> Timestamp:
    """Parse an RFC3339 timestamp string."""
    try:
        ts = Timestamp()
        ts.FromJsonString(rfc3339)
        return ts
    except ValueError as e:
        raise InvalidTimestampError(str(e)) from e


# Event decoding


def decode_event(page: EventPage, type_suffix: str, msg_class) -> Optional[object]:
    """Attempt to decode an event payload if the type URL matches.

    Args:
        page: The event page to decode
        type_suffix: The expected type URL suffix
        msg_class: The protobuf message class to decode into

    Returns:
        The decoded message if type matches and decoding succeeds, None otherwise
    """
    if page is None or not page.HasField("event"):
        return None
    if not type_url_matches(page.event.type_url, type_suffix):
        return None
    try:
        msg = msg_class()
        page.event.Unpack(msg)
        return msg
    except Exception:
        return None


# Construction helpers


def new_cover(
    domain_name: str,
    root: PyUUID,
    correlation_id_val: str = "",
    edition_val: Optional[Edition] = None,
) -> Cover:
    """Create a new Cover with the given parameters."""
    cover = Cover(
        domain=domain_name,
        root=uuid_to_proto(root),
        correlation_id=correlation_id_val,
    )
    if edition_val is not None:
        cover.edition.CopyFrom(edition_val)
    return cover


def new_command_page(sequence: int, command: ProtoAny) -> CommandPage:
    """Create a command page from a sequence and Any message."""
    page = CommandPage(sequence=sequence)
    page.command.CopyFrom(command)
    return page


def new_command_book(cover: Cover, pages: list[CommandPage]) -> CommandBook:
    """Create a CommandBook with the given cover and pages."""
    book = CommandBook()
    book.cover.CopyFrom(cover)
    book.pages.extend(pages)
    return book


def range_selection(lower: int, upper: Optional[int] = None) -> SequenceRange:
    """Create a sequence range selection."""
    r = SequenceRange(lower=lower)
    if upper is not None:
        r.upper = upper
    return r


def temporal_by_sequence(seq: int) -> TemporalQuery:
    """Create a temporal selection as-of a sequence."""
    return TemporalQuery(as_of_sequence=seq)


def temporal_by_time(ts: Timestamp) -> TemporalQuery:
    """Create a temporal selection as-of a timestamp."""
    tq = TemporalQuery()
    tq.as_of_time.CopyFrom(ts)
    return tq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/order.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'examples/order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x65xamples/order.proto\x12\x08\x65xamples\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x01\n\x0b\x43reateOrder\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12#\n\rcustomer_root\x18\x03 \x01(\x0cR\x0c\x63ustomerRoot\x12\x1b\n\tcart_root\x18\x04 \x01(\x0cR\x08\x63\x61rtRoot\"U\n\x14\x41pplyLoyaltyDiscount\x12\x16\n\x06points\x18\x01 \x01(\x05R\x06points\x12%\n\x0e\x64iscount_cents\x18\x02 \x01(\x05R\rdiscountCents\"Y\n\rSubmitPayment\x12%\n\x0epayment_method\x18\x01 \x01(\tR\rpaymentMethod\x12!\n\x0c\x61mount_cents\x18\x02 \x01(\x05R\x0b\x61mountCents\"=\n\x0e\x43onfirmPayment\x12+\n\x11payment_reference\x18\x01 \x01(\tR\x10paymentReference\"%\n\x0b\x43\x61ncelOrder\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\"\xfd\x01\n\x0cOrderCreated\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12%\n\x0esubtotal_cents\x18\x03 \x01(\x05R\rsubtotalCents\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12#\n\rcustomer_root\x18\x05 \x01(\x0cR\x0c\x63ustomerRoot\x12\x1b\n\tcart_root\x18\x06 \x01(\x0cR\x08\x63\x61rtRoot\"\x9b\x01\n\x16LoyaltyDiscountApplied\x12\x1f\n\x0bpoints_used\x18\x01 \x01(\x05R\npointsUsed\x12%\n\x0e\x64iscount_cents\x18\x02 \x01(\x05R\rdiscountCents\x12\x39\n\napplied_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tappliedAt\"\x9b\x01\n\x10PaymentSubmitted\x12%\n\x0epayment_method\x18\x01 \x01(\tR\rpaymentMethod\x12!\n\x0c\x61mount_cents\x18\x02 \x01(\x05R\x0b\x61mountCents\x12=\n\x0csubmitted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bsubmittedAt\"\x9d\x03\n\x0eOrderCompleted\x12*\n\x11\x66inal_total_cents\x18\x01 \x01(\x05R\x0f\x66inalTotalCents\x12%\n\x0epayment_method\x18\x02 \x01(\tR\rpaymentMethod\x12+\n\x11payment_reference\x18\x03 \x01(\tR\x10paymentReference\x12\x32\n\x15loyalty_points_earned\x18\x04 \x01(\x05R\x13loyaltyPointsEarned\x12=\n\x0c\x63ompleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt\x12#\n\rcustomer_root\x18\x06 \x01(\x0cR\x0c\x63ustomerRoot\x12\x1b\n\tcart_root\x18\x07 \x01(\x0cR\x08\x63\x61rtRoot\x12(\n\x05items\x18\x08 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12,\n\x12\x66raud_check_result\x18\t \x01(\tR\x10\x66raudCheckResult\"\x83\x02\n\x0eOrderCancelled\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x12=\n\x0c\x63\x61ncelled_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63\x61ncelledAt\x12.\n\x13loyalty_points_used\x18\x03 \x01(\x05R\x11loyaltyPointsUsed\x12#\n\rcustomer_root\x18\x04 \x01(\x0cR\x0c\x63ustomerRoot\x12(\n\x05items\x18\x05 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12\x1b\n\tcart_root\x18\x06 \x01(\x0cR\x08\x63\x61rtRoot\"\xa6\x01\n\x08LineItem\x12\x1d\n\nproduct_id\x18\x01 \x01(\tR\tproductId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1a\n\x08quantity\x18\x03 \x01(\x05R\x08quantity\x12(\n\x10unit_price_cents\x18\x04 \x01(\x05R\x0eunitPriceCents\x12!\n\x0cproduct_root\x18\x05 \x01(\x0cR\x0bproductRoot\"\x83\x03\n\nOrderState\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12%\n\x0esubtotal_cents\x18\x03 \x01(\x05R\rsubtotalCents\x12%\n\x0e\x64iscount_cents\x18\x04 \x01(\x05R\rdiscountCents\x12.\n\x13loyalty_points_used\x18\x05 \x01(\x05R\x11loyaltyPointsUsed\x12%\n\x0epayment_method\x18\x06 \x01(\tR\rpaymentMethod\x12+\n\x11payment_reference\x18\x07 \x01(\tR\x10paymentReference\x12\x16\n\x06status\x18\x08 \x01(\tR\x06status\x12#\n\rcustomer_root\x18\t \x01(\x0cR\x0c\x63ustomerRoot\x12\x1b\n\tcart_root\x18\n \x01(\x0cR\x08\x63\x61rtRootB\x8e\x01\n\x0c\x63om.examplesB\nOrderProtoP\x01Z2github.com/angzarr/angzarr/proto/examples;examples\xa2\x02\x03\x45XX\xaa\x02\x08\x45xamples\xca\x02\x08\x45xamples\xe2\x02\x14\x45xamples\\GPBMetadata\xea\x02\x08\x45xamplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.examplesB\nOrderProtoP\001Z2github.com/angzarr/angzarr/proto/examples;examples\242\002\003EXX\252\002\010Examples\312\002\010Examples\342\002\024Examples\\GPBMetadata\352\002\010Examples'
  _globals['_CREATEORDER']._serialized_start=68
  _globals['_CREATEORDER']._serialized_end=222
  _globals['_APPLYLOYALTYDISCOUNT']._serialized_start=224
  _globals['_APPLYLOYALTYDISCOUNT']._serialized_end=309
  _globals['_SUBMITPAYMENT']._serialized_start=311
  _globals['_SUBMITPAYMENT']._serialized_end=400
  _globals['_CONFIRMPAYMENT']._serialized_start=402
  _globals['_CONFIRMPAYMENT']._serialized_end=463
  _globals['_CANCELORDER']._serialized_start=465
  _globals['_CANCELORDER']._serialized_end=502
  _globals['_ORDERCREATED']._serialized_start=505
  _globals['_ORDERCREATED']._serialized_end=758
  _globals['_LOYALTYDISCOUNTAPPLIED']._serialized_start=761
  _globals['_LOYALTYDISCOUNTAPPLIED']._serialized_end=916
  _globals['_PAYMENTSUBMITTED']._serialized_start=919
  _globals['_PAYMENTSUBMITTED']._serialized_end=1074
  _globals['_ORDERCOMPLETED']._serialized_start=1077
  _globals['_ORDERCOMPLETED']._serialized_end=1490
  _globals['_ORDERCANCELLED']._serialized_start=1493
  _globals['_ORDERCANCELLED']._serialized_end=1752
  _globals['_LINEITEM']._serialized_start=1755
  _globals['_LINEITEM']._serialized_end=1921
  _globals['_ORDERSTATE']._serialized_start=1924
  _globals['_ORDERSTATE']._serialized_end=2311
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/process_manager.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'angzarr/process_manager.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ngzarr/process_manager.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x85\x01\n\x1cProcessManagerPrepareRequest\x12,\n\x07trigger\x18\x01 \x01(\x0b\x32\x12.angzarr.EventBookR\x07trigger\x12\x37\n\rprocess_state\x18\x02 \x01(\x0b\x32\x12.angzarr.EventBookR\x0cprocessState\"S\n\x1dProcessManagerPrepareResponse\x12\x32\n\x0c\x64\x65stinations\x18\x01 \x03(\x0b\x32\x0e.angzarr.CoverR\x0c\x64\x65stinations\"\xbc\x01\n\x1bProcessManagerHandleRequest\x12,\n\x07trigger\x18\x01 \x01(\x0b\x32\x12.angzarr.EventBookR\x07trigger\x12\x37\n\rprocess_state\x18\x02 \x01(\x0b\x32\x12.angzarr.EventBookR\x0cprocessState\x12\x36\n\x0c\x64\x65stinations\x18\x03 \x03(\x0b\x32\x12.angzarr.EventBookR\x0c\x64\x65stinations\"\x8b\x01\n\x1cProcessManagerHandleResponse\x12\x30\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x14.angzarr.CommandBookR\x08\x63ommands\x12\x39\n\x0eprocess_events\x18\x02 \x01(\x0b\x32\x12.angzarr.EventBookR\rprocessEvents\"\xb5\x01\n\x0eProcessTimeout\x12%\n\x0e\x63orrelation_id\x18\x01 \x01(\tR\rcorrelationId\x12!\n\x0cprocess_type\x18\x02 \x01(\tR\x0bprocessType\x12!\n\x0ctimeout_type\x18\x03 \x01(\tR\x0btimeoutType\x12\x36\n\x08\x64\x65\x61\x64line\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x64\x65\x61\x64line2\x96\x02\n\x15ProcessManagerService\x12L\n\rGetDescriptor\x12\x1d.angzarr.GetDescriptorRequest\x1a\x1c.angzarr.ComponentDescriptor\x12X\n\x07Prepare\x12%.angzarr.ProcessManagerPrepareRequest\x1a&.angzarr.ProcessManagerPrepareResponse\x12U\n\x06Handle\x12$.angzarr.ProcessManagerHandleRequest\x1a%.angzarr.ProcessManagerHandleResponse2\x84\x01\n ProcessManagerCoordinatorService\x12`\n\x11HandleSpeculative\x12$.angzarr.ProcessManagerHandleRequest\x1a%.angzarr.ProcessManagerHandleResponseB\x88\x01\n\x0b\x63om.angzarrB\x13ProcessManagerProtoP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xa2\x02\x03\x41XX\xaa\x02\x07\x41ngzarr\xca\x02\x07\x41ngzarr\xe2\x02\x13\x41ngzarr\\GPBMetadata\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.process_manager_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.angzarrB\023ProcessManagerProtoP\001Z(github.com/angzarr/angzarr/proto/angzarr\242\002\003AXX\252\002\007Angzarr\312\002\007Angzarr\342\002\023Angzarr\\GPBMetadata\352\002\007Angzarr'
  _globals['_PROCESSMANAGERPREPAREREQUEST']._serialized_start=97
  _globals['_PROCESSMANAGERPREPAREREQUEST']._serialized_end=230
  _globals['_PROCESSMANAGERPREPARERESPONSE']._serialized_start=232
  _globals['_PROCESSMANAGERPREPARERESPONSE']._serialized_end=315
  _globals['_PROCESSMANAGERHANDLEREQUEST']._serialized_start=318
  _globals['_PROCESSMANAGERHANDLEREQUEST']._serialized_end=506
  _globals['_PROCESSMANAGERHANDLERESPONSE']._serialized_start=509
  _globals['_PROCESSMANAGERHANDLERESPONSE']._serialized_end=648
  _globals['_PROCESSTIMEOUT']._serialized_start=651
  _globals['_PROCESSTIMEOUT']._serialized_end=832
  _globals['_PROCESSMANAGERSERVICE']._serialized_start=835
  _globals['_PROCESSMANAGERSERVICE']._serialized_end=1113
  _globals['_PROCESSMANAGERCOORDINATORSERVICE']._serialized_start=1116
  _globals['_PROCESSMANAGERCOORDINATORSERVICE']._serialized_end=1248
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/projector.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'angzarr/projector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ngzarr/projector.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\x1a\x1bgoogle/protobuf/empty.proto2\x93\x01\n\x10ProjectorService\x12L\n\rGetDescriptor\x12\x1d.angzarr.GetDescriptorRequest\x1a\x1c.angzarr.ComponentDescriptor\x12\x31\n\x06Handle\x12\x12.angzarr.EventBook\x1a\x13.angzarr.Projection2\xcc\x01\n\x1bProjectorCoordinatorService\x12\x39\n\nHandleSync\x12\x16.angzarr.SyncEventBook\x1a\x13.angzarr.Projection\x12\x34\n\x06Handle\x12\x12.angzarr.EventBook\x1a\x16.google.protobuf.Empty\x12<\n\x11HandleSpeculative\x12\x12.angzarr.EventBook\x1a\x13.angzarr.ProjectionB\x83\x01\n\x0b\x63om.angzarrB\x0eProjectorProtoP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xa2\x02\x03\x41XX\xaa\x02\x07\x41ngzarr\xca\x02\x07\x41ngzarr\xe2\x02\x13\x41ngzarr\\GPBMetadata\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.projector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.angzarrB\016ProjectorProtoP\001Z(github.com/angzarr/angzarr/proto/angzarr\242\002\003AXX\252\002\007Angzarr\312\002\007Angzarr\342\002\023Angzarr\\GPBMetadata\352\002\007Angzarr'
  _globals['_PROJECTORSERVICE']._serialized_start=87
  _globals['_PROJECTORSERVICE']._serialized_end=234
  _globals['_PROJECTORCOORDINATORSERVICE']._serialized_start=237
  _globals['_PROJECTORCOORDINATORSERVICE']._serialized_end=441
# @@protoc_insertion_point(module_scope)
